Skip to contents

Synthetic hubverse format admission quantile forecast for 4 weeks after reference_date = 2024-12-21, paired with admission_history.

Usage

admission_forecast

Format

A tibble with the standard hubverse model output columns.

Details

In a real workflow this comes from a forecasting hub, e.g. hubData::connect_hub() |> collect_hub().